from .utils import dl_progress, mark_executable
from os import path, makedirs
import sys
if sys.version_info[0] >= 3:
    from urllib.request import urlretrieve
else:
    from urllib import urlretrieve


def download_ffmpeg(location):
    location = path.expanduser(location)

    url = "https://github.com/kepoorhampond/ffmpeg-binaries/blob/master"

    platform_types = ["/linux/", "/win32/", "/darwin/"]

    for type in platform_types:
        if sys.platform.startswith(type.replace("/", "")):
            url += type
            files = [
                "ffmpeg",
                "ffprobe"
            ]
            if type == "win32":
                files = [x + ".exe" for x in files]
            for file in files:
                filename = location + file
                if not path.isdir(location):
                    makedirs(location)
                print('Downloading "%s":' % file)
                urlretrieve(url + file + "?raw=true", filename,
                                   reporthook=dl_progress)
                print("")
                if type != "/win32/":
                    mark_executable(filename)


if __name__ == "__main__":
    download_ffmpeg()



from .utils import dl_progress, mark_executable
from os import path, makedirs
import subprocess
import sys
if sys.version_info[0] >= 3:
    from urllib.request import urlretrieve, urlopen
else:
    from urllib import urlretrieve, urlopen


def check_ydl_version(location):
    if path.isdir(location):
        try:
            local_version = subprocess.check_output((location + "youtube-dl \
--version").split(" ")).strip("\n")
        except OSError:
            return True

        remote_version = urlopen("https://youtube-dl.org/").read()
        remote_version = remote_version.rsplit('<a href="latest">\
Latest</a> (v', 1)[1][:10]
        if local_version == remote_version:
            return False
    return True


def update_ydl(location):
    location = path.expanduser(location)
    if check_ydl_version(location):
        windows = (sys.platform == "win32")

        if not windows:
            url = ["https://yt-dl.org/downloads/latest", "youtube-dl"]
        else:
            url = ["https://yt-dl.org/latest", "youtube-dl.exe"]
        filename = location + url[1]

        if not path.isdir(location):
            makedirs(location)

        print('Downloading "youtube-dl":')
        urlretrieve("/".join(url), filename, reporthook=dl_progress)

        if not windows:
            mark_executable(filename)


if __name__ == "__main__":
    update_ydl()



import sys
import argparse
from .ffmpeg import download_ffmpeg
from .ydl import update_ydl


def main():
    parser = argparse.ArgumentParser(
        description="Cross-platform binaries for youtube-dl and ffmpeg"
    )

    parser.add_argument(
        "-f",    "--ffmpeg",
        dest   = "ffmpeg",
        action = "store_true",
        help   = "download ffmpeg binaries"
    )

    parser.add_argument(
        "-y",    "--youtube-dl",
        dest   = "ydl",
        action = "store_true",
        help   = "download/update youtube-dl binary"
    )

    parser.add_argument(
        "-l", "--location",
        dest    = "location",
        default = "bin/",
        help    = 'where to put downloaded files. defaults to \"bin/" ' +
        'in the working directory.',
        type    = str
    )

    args = parser.parse_args()

    if not args.location.endswith("/"):
        args.location += "/"

    if args.ffmpeg:
        download_ffmpeg(args.location)

    if args.ydl:
        update_ydl(args.location)



from sys import stdout
import os
import stat


# Hook to display progress of downloads.
def dl_progress(count, blocks, totalSize):
    stdout.write("\r %3d%%  (%4d / %d pieces)"
                 % (count * blocks * 100 / totalSize, count,
                    (totalSize / blocks) + 1))
    stdout.flush()


# Mark a file as an executable
def mark_executable(filename):
    st = os.stat(filename)
    os.chmod(filename, os.stat(filename).st_mode | stat.S_IEXEC)
